@@ -72,18 +72,6 @@ gst_ffmpeg_avcodec_open (AVCodecContext * avctx, const AVCodec * codec)
   return ret;
 }
 
-int
-gst_ffmpeg_avcodec_close (AVCodecContext * avctx)
-{
-  int ret;
-
-  g_mutex_lock (&gst_avcodec_mutex);
-  ret = avcodec_close (avctx);
-  g_mutex_unlock (&gst_avcodec_mutex);
-
-  return ret;
-}
-
 int
 gst_ffmpeg_av_find_stream_info (AVFormatContext * ic)
 {
@@ -101,7 +89,7 @@ static void
 gst_ffmpeg_log_callback (void *ptr, int level, const char *fmt, va_list vl)
 {
   GstDebugLevel gst_level;
-  gint len = strlen (fmt);
+  gint len;
   gchar *fmt2 = NULL;
 
   switch (level) {
@@ -122,7 +110,12 @@ gst_ffmpeg_log_callback (void *ptr, int level, const char *fmt, va_list vl)
       break;
   }
 
+  /* Don't create lines which won't be needed */
+  if (ffmpeg_debug->threshold < gst_level)
+    return;
+
   /* remove trailing newline as it gets already appended by the logger */
+  len = strlen (fmt);
   if (fmt[len - 1] == '\n') {
     fmt2 = g_strdup (fmt);
     fmt2[len - 1] = '\0';
@@ -162,6 +155,7 @@ plugin_init (GstPlugin * plugin)
   gst_ffmpegdemux_register (plugin);
   gst_ffmpegmux_register (plugin);
   gst_ffmpegdeinterlace_register (plugin);
+  gst_ffmpegvidcmp_register (plugin);
 
   /* Now we can return the pointer to the newly created Plugin object. */
   return TRUE;
